package WWW::Mixi::Scraper::Plugin::ResEcho;

use strict;
use warnings;
use WWW::Mixi::Scraper::Plugin;

sub scrape { warn "This plugin is deprecated"; return [] }

1;

__END__

=head1 NAME

WWW::Mixi::Scraper::Plugin::ResEcho

=head1 DESCRIPTION

This plugin is deprecated.

=head1 METHOD

=head2 scrape

=head1 AUTHOR

Kazuhiro Osawa

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2008 by Kazuhiro Osawa.

This program is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

=cut
